<?php

namespace Drupal\node_alias_history\Form;

use Drupal;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;

/**
 * Implements the Node Alias History form.
 */
class NodeAliasHistoryForm extends FormBase {

  /**
   * Build the Form.
   *
   * @inheritDoc
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $get_nid = $this->getRequest()->query->get('nid');
    $get_alias = $this->getRequest()->query->get('alias');
    $link = Link::createFromRoute($this->t('Reset'), 'node_alias_history.form');
    $form['fieldset'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Search Alias'),
    ];
    $form['fieldset']['nid'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Nid'),
      '#description' => $this->t('Please enter nid'),
      '#default_value' => isset($get_nid) ? $get_nid : '',
      '#element_validate' => ['element_validate_integer_positive'],
    ];
    $form['fieldset']['alias'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Alias'),
      '#description' => $this->t('Please enter Alias'),
      '#default_value' => isset($get_alias) ? $get_alias : '',
    ];
    $form['fieldset']['display_button'] = [
      '#prefix' => '<div class="submit">',
      '#suffix' => $link->toString() . '</div">',
      '#type' => 'submit',
      '#value' => $this->t('Search'),
    ];
    $node_alias_history_rows = node_alias_history_rows();
    $form['markup'] = [
      '#markup' => Drupal::service('renderer')->render($node_alias_history_rows),
    ];
    return $form;
  }

  /**
   * Get the form_id.
   *
   * @inheritDoc
   */
  public function getFormId() {
    return 'node_alias_history_form';
  }

  /**
   * Add submit handler.
   *
   * @inheritDoc
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $nid = $form_state->getValue('nid');
    $alias = $form_state->getValue('alias');
    $form_state->setRedirect(
      'node_alias_history.form',
      [
        'nid' => $nid,
        'alias' => $alias,
      ]
    );
  }

}
